<?php
/*
Plugin Name: 콩디 도메인 체류시간
Description: Tracks total study time for users and displays it at specified location using shortcode.
Version: 2.5
Author: Kongdy
*/

// 1. 메뉴 추가하기
function domain_time_tracker_menu() {
    add_menu_page('도메인 체류시간', '도메인 체류시간', 'manage_options', 'domain-time-tracker', 'domain_time_tracker_settings_page');
}
add_action('admin_menu', 'domain_time_tracker_menu');

// 2. 설정 필드 등록하기
function domain_time_tracker_register_settings() {
    register_setting('domain_time_tracker_settings', 'tracker_title_text');
    register_setting('domain_time_tracker_settings', 'tracker_title_size');
    register_setting('domain_time_tracker_settings', 'tracker_title_color');
    register_setting('domain_time_tracker_settings', 'tracker_time_size');
    register_setting('domain_time_tracker_settings', 'tracker_time_color');
    register_setting('domain_time_tracker_settings', 'tracker_background_color');
}
add_action('admin_init', 'domain_time_tracker_register_settings');

// 3. 설정 페이지 UI 생성하기
function domain_time_tracker_settings_page() {
    ?>
    <div class="wrap">
      <a href="https://xn--hy1b53d22msjebow.com/%EB%AC%B8%EC%9D%98-%EA%B2%8C%EC%8B%9C%ED%8C%90" class="button button-primary kongdy-contact-button" target="_blank">문의하기</a>
 
        <h1>도메인 체류시간 설정</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('domain_time_tracker_settings');
            do_settings_sections('domain_time_tracker_settings');
            ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">제목 문구</th>
                    <td><input type="text" name="tracker_title_text" value="<?php echo esc_attr(get_option('tracker_title_text', '도메인 체류 시간')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">제목 글자 크기</th>
                    <td><input type="number" name="tracker_title_size" value="<?php echo esc_attr(get_option('tracker_title_size', 15)); ?>" /> px</td>
                </tr>
                <tr valign="top">
                    <th scope="row">제목 글자 색상</th>
                    <td><input type="color" name="tracker_title_color" value="<?php echo esc_attr(get_option('tracker_title_color', '#190006')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">시간 글자 크기</th>
                    <td><input type="number" name="tracker_time_size" value="<?php echo esc_attr(get_option('tracker_time_size', 16)); ?>" /> px</td>
                </tr>
                <tr valign="top">
                    <th scope="row">시간 글자 색상</th>
                    <td><input type="color" name="tracker_time_color" value="<?php echo esc_attr(get_option('tracker_time_color', '#efb701')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">배경 색상</th>
                    <td><input type="color" name="tracker_background_color" value="<?php echo esc_attr(get_option('tracker_background_color', '#FBF7F4')); ?>" /></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// 4. 설정 값을 가져와서 UI에 적용하기
function domain_time_tracker_shortcode() {
    $title_text = esc_attr(get_option('tracker_title_text', '총 공부 시간'));
    $title_size = esc_attr(get_option('tracker_title_size', 15));
    $title_color = esc_attr(get_option('tracker_title_color', '#190006'));
    $time_size = esc_attr(get_option('tracker_time_size', 16));
    $time_color = esc_attr(get_option('tracker_time_color', '#efb701'));
    $background_color = esc_attr(get_option('tracker_background_color', '#FBF7F4'));

    ob_start();
    ?>
    <a href="https://xn--hy1b53d22msjebow.com/" target="_blank" style="display: block; text-align: center; background-color: <?php echo $background_color; ?>; padding: 20px; text-decoration: none; width: 100%; box-sizing: border-box; border: 1px solid #DBDBDB; box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);">
        <span style="display: block; font-size: <?php echo $title_size; ?>px; font-weight: bold; color: <?php echo $title_color; ?>; margin-bottom: 10px;"><?php echo $title_text; ?></span>
        <span id="domain-time" style="display: block; font-size: <?php echo $time_size; ?>px; font-weight: bold; color: <?php echo $time_color; ?>;"></span>
    </a>
    <script>
        let 누적시간 = localStorage.getItem('누적시간') ? parseInt(localStorage.getItem('누적시간')) : 0;
        const 시작시간 = new Date().getTime();

        // 시간 문자열 생성 함수
        function 시간문자열(시간) {
            let 초 = Math.floor(시간 / 1000);
            let 분 = Math.floor(초 / 60);
            let 시 = Math.floor(분 / 60);
            초 %= 60;
            분 %= 60;

            let 출력문 = "";
            if (시 > 0) 출력문 += `${시}시간 `;
            if (분 > 0) 출력문 += `${분}분 `;
            출력문 += `${초}초`;

            return 출력문;
        }

        // 처음 로드 시 시간을 즉시 표시
        document.getElementById('domain-time').innerText = 시간문자열(누적시간);

        // 매초마다 시간 업데이트
        setInterval(function() {
            const 현재시간 = new Date().getTime();
            const 걸린시간 = 현재시간 - 시작시간;
            const 총걸린시간 = 걸린시간 + 누적시간;

            document.getElementById('domain-time').innerText = 시간문자열(총걸린시간);
            localStorage.setItem('누적시간', 총걸린시간);
        }, 1000);
    </script>
    <?php
    return ob_get_clean();
}

// Register the shortcode with the name 'time1'
add_shortcode('time1', 'domain_time_tracker_shortcode');
